@@ -189,7 +189,7 @@ class TestGemPackage < Gem::Package::TarTestCase
       File.symlink("code.rb", "lib/code_sym.rb")
       File.symlink("../lib/code.rb", "lib/code_sym2.rb")
     rescue Errno::EACCES => e
-      if win_platform?
+      if Gem.win_platform?
         pend "symlink - must be admin with no UAC on Windows"
       else
         raise e
@@ -287,8 +287,8 @@ class TestGemPackage < Gem::Package::TarTestCase
 
     assert_equal [PUBLIC_CERT.to_pem], reader.spec.cert_chain
 
-    assert_equal %w[metadata.gz       metadata.gz.sig
-                    data.tar.gz       data.tar.gz.sig
+    assert_equal %w[metadata.gz metadata.gz.sig
+                    data.tar.gz data.tar.gz.sig
                     checksums.yaml.gz checksums.yaml.gz.sig],
                  reader.files
 
@@ -330,8 +330,8 @@ class TestGemPackage < Gem::Package::TarTestCase
 
     assert_equal [PUBLIC_CERT.to_pem], reader.spec.cert_chain
 
-    assert_equal %w[metadata.gz       metadata.gz.sig
-                    data.tar.gz       data.tar.gz.sig
+    assert_equal %w[metadata.gz metadata.gz.sig
+                    data.tar.gz data.tar.gz.sig
                     checksums.yaml.gz checksums.yaml.gz.sig],
                  reader.files
 
@@ -393,8 +393,8 @@ class TestGemPackage < Gem::Package::TarTestCase
 
     assert_equal spec, reader.spec
 
-    assert_equal %w[metadata.gz       metadata.gz.sig
-                    data.tar.gz       data.tar.gz.sig
+    assert_equal %w[metadata.gz metadata.gz.sig
+                    data.tar.gz data.tar.gz.sig
                     checksums.yaml.gz checksums.yaml.gz.sig],
                  reader.files
 
@@ -430,14 +430,41 @@ class TestGemPackage < Gem::Package::TarTestCase
 
     assert_equal spec, reader.spec
 
-    assert_equal %w[metadata.gz       metadata.gz.sig
-                    data.tar.gz       data.tar.gz.sig
+    assert_equal %w[metadata.gz metadata.gz.sig
+                    data.tar.gz data.tar.gz.sig
                     checksums.yaml.gz checksums.yaml.gz.sig],
                  reader.files
 
     assert_equal %w[lib/code.rb], reader.contents
   end
 
+  def test_build_modified_platform
+    spec = quick_gem "a", "1" do |s|
+      s.files = %w[lib/code.rb]
+      s.platform = Gem::Platform.new "x86_64-linux"
+    end
+
+    spec.platform = Gem::Platform.new "java"
+
+    FileUtils.mkdir "lib"
+
+    File.open "lib/code.rb", "w" do |io|
+      io.write "# lib/code.rb"
+    end
+
+    package = Gem::Package.new spec.file_name
+    package.spec = spec
+
+    package.build
+
+    assert_path_exist spec.file_name
+
+    reader = Gem::Package.new spec.file_name
+    assert reader.verify
+
+    assert_equal spec, reader.spec
+  end
+
   def test_raw_spec
     data_tgz = util_tar_gz {}
 
@@ -482,7 +509,7 @@ class TestGemPackage < Gem::Package::TarTestCase
     mask = 0o100666 & (~File.umask)
 
     assert_equal mask.to_s(8), File.stat(extracted).mode.to_s(8) unless
-      win_platform?
+      Gem.win_platform?
   end
 
   def test_extract_files_empty
@@ -512,7 +539,7 @@ class TestGemPackage < Gem::Package::TarTestCase
   end
 
   def test_extract_file_permissions
-    pend "chmod not supported" if win_platform?
+    pend "chmod not supported" if Gem.win_platform?
 
     gem_with_long_permissions = File.expand_path("packages/Bluebie-legs-0.6.2.gem", __dir__)
 
@@ -539,7 +566,7 @@ class TestGemPackage < Gem::Package::TarTestCase
       package.extract_tar_gz tgz_io, @destination
     end
 
-    assert_equal("installing into parent path /absolute.rb of " +
+    assert_equal("installing into parent path /absolute.rb of " \
                  "#{@destination} is not allowed", e.message)
   end
 
@@ -559,7 +586,7 @@ class TestGemPackage < Gem::Package::TarTestCase
     begin
       package.extract_tar_gz tgz_io, @destination
     rescue Errno::EACCES => e
-      if win_platform?
+      if Gem.win_platform?
         pend "symlink - must be admin with no UAC on Windows"
       else
         raise e
@@ -638,7 +665,7 @@ class TestGemPackage < Gem::Package::TarTestCase
     destination_subdir = File.join @destination, "subdir"
     FileUtils.mkdir_p destination_subdir
 
-    expected_exceptions = win_platform? ? [Gem::Package::SymlinkError, Errno::EACCES] : [Gem::Package::SymlinkError]
+    expected_exceptions = Gem.win_platform? ? [Gem::Package::SymlinkError, Errno::EACCES] : [Gem::Package::SymlinkError]
 
     e = assert_raise(*expected_exceptions) do
       package.extract_tar_gz tgz_io, destination_subdir
@@ -646,7 +673,7 @@ class TestGemPackage < Gem::Package::TarTestCase
 
     pend "symlink - must be admin with no UAC on Windows" if Errno::EACCES === e
 
-    assert_equal("installing symlink 'lib/link' pointing to parent path #{@destination} of " +
+    assert_equal("installing symlink 'lib/link' pointing to parent path #{@destination} of " \
                 "#{destination_subdir} is not allowed", e.message)
 
     assert_path_not_exist File.join(@destination, "outside.txt")
@@ -673,7 +700,7 @@ class TestGemPackage < Gem::Package::TarTestCase
       tar.add_symlink "link/dir", ".", 16_877
     end
 
-    expected_exceptions = win_platform? ? [Gem::Package::SymlinkError, Errno::EACCES] : [Gem::Package::SymlinkError]
+    expected_exceptions = Gem.win_platform? ? [Gem::Package::SymlinkError, Errno::EACCES] : [Gem::Package::SymlinkError]
 
     e = assert_raise(*expected_exceptions) do
       package.extract_tar_gz tgz_io, destination_subdir
@@ -681,7 +708,7 @@ class TestGemPackage < Gem::Package::TarTestCase
 
     pend "symlink - must be admin with no UAC on Windows" if Errno::EACCES === e
 
-    assert_equal("installing symlink 'link' pointing to parent path #{destination_user_dir} of " +
+    assert_equal("installing symlink 'link' pointing to parent path #{destination_user_dir} of " \
                 "#{destination_subdir} is not allowed", e.message)
 
     assert_path_exist destination_user_subdir
@@ -760,12 +787,10 @@ class TestGemPackage < Gem::Package::TarTestCase
     package = Gem::Package.new @gem
 
     file = "file.rb".dup
-    file.taint if RUBY_VERSION < "2.7"
 
     destination = package.install_location file, @destination
 
     assert_equal File.join(@destination, "file.rb"), destination
-    refute destination.tainted? if RUBY_VERSION < "2.7"
   end
 
   def test_install_location_absolute
@@ -775,7 +800,7 @@ class TestGemPackage < Gem::Package::TarTestCase
       package.install_location "/absolute.rb", @destination
     end
 
-    assert_equal("installing into parent path /absolute.rb of " +
+    assert_equal("installing into parent path /absolute.rb of " \
                  "#{@destination} is not allowed", e.message)
   end
 
@@ -799,12 +824,10 @@ class TestGemPackage < Gem::Package::TarTestCase
     package = Gem::Package.new @gem
 
     file = "foo//file.rb".dup
-    file.taint if RUBY_VERSION < "2.7"
 
     destination = package.install_location file, @destination
 
     assert_equal File.join(@destination, "foo", "file.rb"), destination
-    refute destination.tainted? if RUBY_VERSION < "2.7"
   end
 
   def test_install_location_relative
@@ -816,7 +839,7 @@ class TestGemPackage < Gem::Package::TarTestCase
 
     parent = File.expand_path File.join @destination, "../relative.rb"
 
-    assert_equal("installing into parent path #{parent} of " +
+    assert_equal("installing into parent path #{parent} of " \
                  "#{@destination} is not allowed", e.message)
   end
 
@@ -831,13 +854,15 @@ class TestGemPackage < Gem::Package::TarTestCase
 
     parent = File.expand_path File.join @destination, filename
 
-    assert_equal("installing into parent path #{parent} of " +
+    assert_equal("installing into parent path #{parent} of " \
                  "#{@destination} is not allowed", e.message)
   end
 
   def test_load_spec
     entry = StringIO.new Gem::Util.gzip @spec.to_yaml
-    def entry.full_name() "metadata.gz" end
+    def entry.full_name
+      "metadata.gz"
+    end
 
     package = Gem::Package.new "nonexistent.gem"
 
@@ -1078,8 +1103,8 @@ class TestGemPackage < Gem::Package::TarTestCase
       package.verify
     end
 
-    assert_match %r{^No such file or directory}, e.message
-    assert_match %r{nonexistent.gem$},           e.message
+    assert_match(/^No such file or directory/, e.message)
+    assert_match(/nonexistent.gem$/,           e.message)
   end
 
   def test_verify_duplicate_file
@@ -1166,10 +1191,21 @@ class TestGemPackage < Gem::Package::TarTestCase
         # write bogus data.tar.gz to foil signature
         bogus_data = Gem::Util.gzip "hello"
         fake_signer = Class.new do
-          def digest_name; "SHA512"; end
-          def digest_algorithm; OpenSSL::Digest(:SHA512).new; end
-          def key; "key"; end
-          def sign(*); "fake_sig"; end
+          def digest_name
+            "SHA512"
+          end
+
+          def digest_algorithm
+            OpenSSL::Digest(:SHA512).new
+          end
+
+          def key
+            "key"
+          end
+
+          def sign(*)
+            "fake_sig"
+          end
         end
         gem.add_file_signed "data2.tar.gz", 0o444, fake_signer.new do |io|
           io.write bogus_data
@@ -1213,7 +1249,9 @@ class TestGemPackage < Gem::Package::TarTestCase
 
   def test_verify_entry
     entry = Object.new
-    def entry.full_name() raise ArgumentError, "whatever" end
+    def entry.full_name
+      raise ArgumentError, "whatever"
+    end
 
     package = Gem::Package.new @gem
 
@@ -1240,11 +1278,15 @@ class TestGemPackage < Gem::Package::TarTestCase
       $good_name = vm
 
       entry = Object.new
-      def entry.full_name() $good_name end
+      def entry.full_name
+        $good_name
+      end
 
       package = Gem::Package.new(@gem)
       package.instance_variable_set(:@files, [])
-      def package.load_spec(entry) $spec_loaded = true end
+      def package.load_spec(entry)
+        $spec_loaded = true
+      end
 
       package.verify_entry(entry)
 
@@ -1257,11 +1299,15 @@ class TestGemPackage < Gem::Package::TarTestCase
       $bad_name = vm
 
       entry = Object.new
-      def entry.full_name() $bad_name end
+      def entry.full_name
+        $bad_name
+      end
 
       package = Gem::Package.new(@gem)
       package.instance_variable_set(:@files, [])
-      def package.load_spec(entry) $spec_loaded = true end
+      def package.load_spec(entry)
+        $spec_loaded = true
+      end
 
       package.verify_entry(entry)
 
