@@ -6,17 +6,16 @@ class CertificateBuilder
   attr_reader :start
 
   def initialize(key_size = 2048)
-    @start          = Time.utc 2012, 0o1, 0o1, 0o0, 0o0, 0o0
+    @start          = Time.utc 2012, 1, 1, 0, 0, 0
     @end_of_time    = Time.utc 9999, 12, 31, 23, 59, 59
-    @end_of_time_32 = Time.utc 2038, 0o1, 19, 0o3, 14, 0o7
+    @end_of_time_32 = Time.utc 2038, 1, 19, 3, 14, 7
 
     @key_size = key_size
     @serial = 0
   end
 
   def create_certificates(key, subject, issuer_key = key, issuer_cert = nil,
-                          not_before: @start, not_after: :end_of_time,
-                          is_ca: false)
+    not_before: @start, not_after: :end_of_time, is_ca: false)
     certificates = []
 
     not_before, not_before_32 = validity_for not_before
@@ -34,7 +33,7 @@ class CertificateBuilder
   end
 
   def create_certificate(key, subject, issuer_key, issuer_cert,
-                         not_before, not_after, is_ca)
+    not_before, not_after, is_ca)
     cert = OpenSSL::X509::Certificate.new
     issuer_cert ||= cert # if not specified, create self signing cert
 
@@ -160,10 +159,10 @@ keys.each do |name, key|
   File.write dest, key.to_pem
 end
 
-# Create an encrypted private key protected by a passhrase from the new keys[:private]
+# Create an encrypted private key protected by a passphrase from the new keys[:private]
 # it has to be the same as is in # test/rubygems/helper.rb in PRIVATE_KEY_PASSPHRASE
 dest = File.join base_dir, "encrypted_private_key.pem"
-File.write dest, keys[:private].to_pem(*[ OpenSSL::Cipher.new("aes-256-cbc"), "Foo bar"])
+File.write dest, keys[:private].to_pem(OpenSSL::Cipher.new("aes-256-cbc"), "Foo bar")
 
 certs.each do |name, (cert, cert_32)|
   dest = File.join base_dir, "#{name}_cert.pem"
